==================
``cavcalc.output``
==================

.. automodule:: cavcalc.output

.. currentmodule:: cavcalc.output

Classes
=======

.. autosummary::
    :toctree: output/

    Output

Functions
=========

.. autosummary::
    :toctree: generated/

    is_dual
